package com.ynet.life.base;

import com.ynet.gene.core.Context;
import com.ynet.life.exception.TranFailException;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/* loaded from: com_ynet_life_base.jar:com/ynet/life/base/LifeErrorInfo.class */
public class LifeErrorInfo {
    private String errorCode;
    private String language;
    private String showMsg;
    private int level;
    private String returnPage;
    private String systemCode;
    private static Pattern pattern = Pattern.compile("\\$\\{(\\w+)\\}");

    public LifeErrorInfo(String errorCode, String language, String showMessage, int level, String returnPage) {
        this.errorCode = errorCode;
        this.language = language;
        this.showMsg = showMessage;
        this.level = level;
        this.returnPage = returnPage;
    }

    public LifeErrorInfo(String errorCode, String language, String showMessage, int level, String returnPage, String systemCode) {
        this.errorCode = errorCode;
        this.language = language;
        this.showMsg = showMessage;
        this.level = level;
        this.returnPage = returnPage;
        this.systemCode = systemCode;
    }

    public String getErrorCode() {
        return this.errorCode;
    }

    public String getLanguage() {
        return this.language;
    }

    public String getShowMsg() {
        return this.showMsg;
    }

    public String getShowMsgJSON() {
        return toJSon(this.showMsg);
    }

    public String getShowMsg(Context context) throws TranFailException {
        if (this.showMsg == null || "".equals(this.showMsg)) {
            return this.showMsg;
        }
        Matcher m = pattern.matcher(this.showMsg);
        StringBuffer sb = new StringBuffer();
        while (m.find()) {
            String field = m.group(1);
            m.appendReplacement(sb, (String) context.get(field));
        }
        m.appendTail(sb);
        return sb.toString();
    }

    public int getLevel() {
        return this.level;
    }

    public String getReturnPage() {
        return this.returnPage;
    }

    public void setReturnPage(String returnPage) {
        this.returnPage = returnPage;
    }

    public String getSystemCode() {
        return this.systemCode;
    }

    public void setSystemCode(String systemCode) {
        this.systemCode = systemCode;
    }

    public String toString() {
        StringBuffer retValue = new StringBuffer();
        retValue.append("LifeErrorInfo ( ").append(super.toString()).append("    errorCode = ").append(this.errorCode).append("    language = ").append(this.language).append("    showMsg = ").append(this.showMsg).append("    level = ").append(this.level).append("    returnPage = ").append(this.returnPage).append("     )");
        return retValue.toString();
    }

    public String toJSon(String value) {
        if (value != null) {
            StringBuffer str = new StringBuffer();
            String s = value.toString();
            int len = s != null ? s.length() : 0;
            for (int i = 0; i < len; i++) {
                char lChar = s.charAt(i);
                if (lChar == '\n') {
                    str.append("\\n");
                } else if (lChar == '\r') {
                    str.append("\\r");
                } else if (lChar == '\t') {
                    str.append("\\t");
                } else if (lChar == '\b') {
                    str.append("\\b");
                } else if (lChar == '\f') {
                    str.append("\\f");
                } else if (lChar == '\"') {
                    str.append("\\\"");
                } else if (lChar == '\\') {
                    str.append("\\\\");
                } else {
                    str.append(lChar);
                }
            }
            return str.toString();
        }
        return "null";
    }
}
